@@ -9,11 +9,11 @@
  *
  *	ASSUMPTION:  sizeof(long) >= sizeof(void*)
  *
- * Portions Copyright (c) 1996-2002, PostgreSQL Global Development Group
+ * Portions Copyright (c) 1996-2003, PostgreSQL Global Development Group
  * Portions Copyright (c) 1994, Regents of the University of California
  *
  * IDENTIFICATION
- *	  $Header: /cvsroot/pgsql-server/src/interfaces/libpgtcl/Attic/pgtclId.c,v 1.37.2.2 2003/02/01 00:22:23 tgl Exp $
+ *	  $Header: /cvsroot/pgsql-server/src/interfaces/libpgtcl/Attic/pgtclId.c,v 1.43 2003/08/04 02:40:16 momjian Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -218,7 +218,8 @@ PgSetConnectionId(Tcl_Interp *interp, PGconn *conn)
  * Get back the connection from the Id
  */
 PGconn *
-PgGetConnectionId(Tcl_Interp *interp, char *id, Pg_ConnectionId ** connid_p)
+PgGetConnectionId(Tcl_Interp *interp, CONST84 char *id,
+				  Pg_ConnectionId ** connid_p)
 {
 	Tcl_Channel conn_chan;
 	Pg_ConnectionId *connid;
@@ -295,14 +296,14 @@ PgDelConnectionId(DRIVER_DEL_PROTO)
 	 * the socket itself!
 	 *
 	 * XXX Unfortunately, while this works fine if we are closing due to
-	 * explicit pg_disconnect, all Tcl versions through 8.4.1 dump core
-	 * if we try to do it during interpreter shutdown.  Not clear why.
-	 * For now, we kill the channel during pg_disconnect, but during interp
-	 * shutdown we just accept leakage of the (fairly small) amount of memory
-	 * taken for the channel state representation.
-	 * (Note we are not leaking a socket, since libpq closed that already.)
-	 * We tell the difference between pg_disconnect and interpreter shutdown
-	 * by testing for interp != NULL, which is an undocumented but apparently
+	 * explicit pg_disconnect, all Tcl versions through 8.4.1 dump core if
+	 * we try to do it during interpreter shutdown.  Not clear why. For
+	 * now, we kill the channel during pg_disconnect, but during interp
+	 * shutdown we just accept leakage of the (fairly small) amount of
+	 * memory taken for the channel state representation. (Note we are not
+	 * leaking a socket, since libpq closed that already.) We tell the
+	 * difference between pg_disconnect and interpreter shutdown by
+	 * testing for interp != NULL, which is an undocumented but apparently
 	 * safe way to tell.
 	 */
 #if TCL_MAJOR_VERSION >= 8
@@ -329,7 +330,7 @@ PgDelConnectionId(DRIVER_DEL_PROTO)
  * is probably just not clearing result handles like they should.
  */
 int
-PgSetResultId(Tcl_Interp *interp, char *connid_c, PGresult *res)
+PgSetResultId(Tcl_Interp *interp, CONST84 char *connid_c, PGresult *res)
 {
 	Tcl_Channel conn_chan;
 	Pg_ConnectionId *connid;
@@ -387,7 +388,7 @@ PgSetResultId(Tcl_Interp *interp, char *connid_c, PGresult *res)
 }
 
 static int
-getresid(Tcl_Interp *interp, char *id, Pg_ConnectionId ** connid_p)
+getresid(Tcl_Interp *interp, CONST84 char *id, Pg_ConnectionId ** connid_p)
 {
 	Tcl_Channel conn_chan;
 	char	   *mark;
@@ -429,7 +430,7 @@ getresid(Tcl_Interp *interp, char *id, Pg_ConnectionId ** connid_p)
  * Get back the result pointer from the Id
  */
 PGresult *
-PgGetResultId(Tcl_Interp *interp, char *id)
+PgGetResultId(Tcl_Interp *interp, CONST84 char *id)
 {
 	Pg_ConnectionId *connid;
 	int			resid;
@@ -447,7 +448,7 @@ PgGetResultId(Tcl_Interp *interp, char *id)
  * Remove a result Id from the hash tables
  */
 void
-PgDelResultId(Tcl_Interp *interp, char *id)
+PgDelResultId(Tcl_Interp *interp, CONST84 char *id)
 {
 	Pg_ConnectionId *connid;
 	int			resid;
@@ -463,7 +464,7 @@ PgDelResultId(Tcl_Interp *interp, char *id)
  * Get the connection Id from the result Id
  */
 int
-PgGetConnByResultId(Tcl_Interp *interp, char *resid_c)
+PgGetConnByResultId(Tcl_Interp *interp, CONST84 char *resid_c)
 {
 	char	   *mark;
 	Tcl_Channel conn_chan;
@@ -475,7 +476,8 @@ PgGetConnByResultId(Tcl_Interp *interp, char *resid_c)
 	*mark = '.';
 	if (conn_chan && Tcl_GetChannelType(conn_chan) == &Pg_ConnType)
 	{
-		Tcl_SetResult(interp, Tcl_GetChannelName(conn_chan), TCL_VOLATILE);
+		Tcl_SetResult(interp, (char *) Tcl_GetChannelName(conn_chan),
+					  TCL_VOLATILE);
 		return TCL_OK;
 	}
 
@@ -552,7 +554,7 @@ Pg_Notify_EventProc(Tcl_Event *evPtr, int flags)
 	if (event->connid == NULL)
 	{
 		if (event->notify)
-			PQfreeNotify(event->notify);
+			PQfreemem(event->notify);
 		return 1;
 	}
 
@@ -632,7 +634,7 @@ Pg_Notify_EventProc(Tcl_Event *evPtr, int flags)
 	Tcl_Release((ClientData) event->connid);
 
 	if (event->notify)
-		PQfreeNotify(event->notify);
+		PQfreemem(event->notify);
 
 	return 1;
 }
